@@ -99,6 +99,7 @@ typedef struct _ConnectionData {
 
 static GHashTable *pending_requests = NULL;
 static GHashTable *cddb_cache = NULL;
+static GList *cddb_slaves = NULL;
 
 static void do_hello (ConnectionData *cd);
 
@@ -116,7 +117,8 @@ cddb_slave_notify_listeners (CDDBSlave *cddb,
 {
 	CORBA_any any;
 	GNOME_Media_CDDBSlave2_QueryResult qr;
-
+	GList *l;
+	
 	g_return_if_fail (cddb != NULL);
 	g_return_if_fail (IS_CDDB_SLAVE (cddb));
 
@@ -129,9 +131,16 @@ cddb_slave_notify_listeners (CDDBSlave *cddb,
 	if (cddb_debugging == TRUE) {
 		g_print ("CDDB: Notifying listeners.\n");
 	}
-	bonobo_event_source_notify_listeners (cddb->priv->event_source,
-					      CDDB_SLAVE_CDDB_FINISHED,
-					      &any, NULL);
+
+	for (l = cddb_slaves; l; l = l->next) {
+		CDDBSlave *slave;
+
+		slave = CDDB_SLAVE (l->data);
+		
+		bonobo_event_source_notify_listeners (slave->priv->event_source,
+						      CDDB_SLAVE_CDDB_FINISHED,
+						      &any, NULL);
+	}
 }
 
 static gboolean
@@ -216,7 +225,7 @@ static void
 do_goodbye (ConnectionData *cd)
 {
 	char *quit;
-	gsize bytes_writen;
+	guint bytes_writen;
 	GIOError status;
 	
 	/* Send quit command */
@@ -374,7 +383,7 @@ do_read (ConnectionData *cd,
 	 const char *dtitle)
 {
 	char *query;
-	gsize bytes_writen;
+	guint bytes_writen;
 	GIOError status;
 	
 	/* Send read command */
@@ -400,9 +409,16 @@ create_model_from_list (GList *list)
 
 	for (l = list; l; l = l->next) {
 		char **vector;
-
+		char *end;
+		
 		vector = (char **) l->data;
-
+		/* Strip newlines and \r */
+		vector[2][strlen (vector[2]) - 1] = 0;
+		end = strchr (vector[2], '\r');
+		if (end != NULL) {
+			*end = 0;
+		}
+		
 		gtk_list_store_append (store, &iter);
 		gtk_list_store_set (store, &iter, 0, vector[0], 1, vector[1], 2, vector[2], -1);
 	}
@@ -425,11 +441,12 @@ display_results (ConnectionData *cd)
 	window = gtk_dialog_new_with_buttons (_("Multiple matches..."),
 					      NULL, 0,
 					      GTK_STOCK_CANCEL, 0, GTK_STOCK_OK, 1, NULL);
+	gtk_window_set_default_size (GTK_WINDOW (window), 280, 256);
 
 	label = gtk_label_new (_("There were multiple matches found in the database.\n"
 				 "Below is a list of possible matches, please choose the "
 				 "best match"));
-	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (window)->vbox), label, TRUE, TRUE, 0);
+	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (window)->vbox), label, FALSE, FALSE, 0);
 	gtk_widget_show (label);
 	
 	model = create_model_from_list (cd->matches);
@@ -657,7 +674,7 @@ static void
 do_query (ConnectionData *cd)
 {
 	char *query;
-	gsize bytes_writen;
+	guint bytes_writen;
 	GIOError status;
 	
 	/* Send query command */
@@ -727,7 +744,7 @@ static void
 do_hello (ConnectionData *cd)
 {
 	char *hello;
-	gsize bytes_writen;
+	guint bytes_writen;
 	GIOError status;
 	
 	/* Send the Hello command
@@ -828,6 +845,7 @@ read_from_server (GIOChannel *iochannel,
 		  GIOCondition condition,
 		  gpointer data)
 {
+	GIOStatus status;
 	ConnectionData *cd = data;
 
 	if (condition & (G_IO_ERR | G_IO_HUP | G_IO_NVAL)) {
@@ -848,15 +866,14 @@ read_from_server (GIOChannel *iochannel,
 		goto error;
 	}
 
-	if (condition & G_IO_IN) {
-		GIOError error;
+	if (condition & (G_IO_IN | G_IO_PRI)) {
 		char *buffer;
 		gsize bytes_read;
 
 		/* Read the data into our buffer */
-		error = g_io_channel_read_line (iochannel, &buffer,
+		status = g_io_channel_read_line (iochannel, &buffer,
 						&bytes_read, NULL, NULL);
-		while (error == G_IO_STATUS_NORMAL) {
+		while (status == G_IO_STATUS_NORMAL) {
 			gboolean more = FALSE;
 			
 			switch (cd->mode) {
@@ -889,16 +906,18 @@ read_from_server (GIOChannel *iochannel,
 			g_free (buffer);
 
 			if (more == TRUE) {
-				error = g_io_channel_read_line (iochannel, &buffer,
-								&bytes_read,
-								NULL, NULL);
+				status = g_io_channel_read_line (iochannel, &buffer,
+								 &bytes_read,
+								 NULL, NULL);
 			} else {
 				break;
 			}
 		}
 	}
 
-	return TRUE;
+	if (status == G_IO_STATUS_NORMAL ||
+	    status == G_IO_STATUS_AGAIN)
+		return TRUE;
 
  error:
 	clear_entry_from_cache (cd->discid);
@@ -1047,6 +1066,7 @@ impl_GNOME_Media_CDDBSlave2_save (PortableServer_Servant servant,
 				  const CORBA_char *discid,
 				  CORBA_Environment *ev)
 {
+	CDDBSlave *cddb;
 	CDDBEntry *entry;
 	gboolean write_ret;
 	
@@ -1061,7 +1081,13 @@ impl_GNOME_Media_CDDBSlave2_save (PortableServer_Servant servant,
 	write_ret = cddb_entry_write_to_file (entry);
 	if (write_ret == FALSE) {
 		/* Exception */
+		return;
 	}
+
+	cddb = cddb_slave_from_servant (servant);
+	/* FIXME: Should we only emit the changed signal here,
+	   or in the set* calls? */
+	cddb_slave_notify_listeners (cddb, discid, GNOME_Media_CDDBSlave2_OK);
 }
 
 static CORBA_char *
@@ -1499,6 +1525,9 @@ finalize (GObject *object)
 	if (priv == NULL)
 		return;
 
+	/* Remove this slave from our list */
+	cddb_slaves = g_list_remove (cddb_slaves, cddb);
+	
 	g_free (priv->server);
 	g_free (priv->name);
 	g_free (priv->hostname);
@@ -1602,6 +1631,10 @@ cddb_slave_new_full (const char *server,
 	bonobo_object_add_interface (BONOBO_OBJECT (cddb),
 				     BONOBO_OBJECT (priv->event_source));
 
+
+	/* Add this slave to our global list of slaves */
+	cddb_slaves = g_list_prepend (cddb_slaves, cddb);
+	
 	return cddb;
 }
 /**
