@@ -45,6 +45,7 @@ typedef struct _GSRWindowPipeline {
 	GstElement *pipeline;
 
 	GstElement *src, *sink;
+	guint32 state_change_id;
 } GSRWindowPipeline;
 
 struct _GSRWindowPrivate {
@@ -73,12 +74,25 @@ struct _GSRWindowPrivate {
 	int n_channels, bitrate, samplerate;
 	gboolean has_file;
 	gboolean dirty;
+
+	guint32 tick_id; /* tick_callback timeout ID */
 };
 
 static BonoboWindowClass *parent_class = NULL;
 
 static char *temppath = NULL;
 
+static void
+shutdown_pipeline (GSRWindowPipeline *pipe)
+{
+	if (pipe->state_change_id > 0) {
+		g_signal_handler_disconnect (G_OBJECT (pipe->pipeline),
+					     pipe->state_change_id);
+	}
+	gst_element_set_state (pipe->pipeline, GST_STATE_NULL);
+	gst_object_unref (GST_OBJECT (pipe->pipeline));	
+}
+
 static void
 finalize (GObject *object)
 {
@@ -92,12 +106,14 @@ finalize (GObject *object)
 		return;
 	}
 
-	gst_element_set_state (priv->play->pipeline, GST_STATE_NULL);
-	gst_object_unref (GST_OBJECT (priv->play->pipeline));
+	if (priv->tick_id > 0) {
+		g_source_remove (priv->tick_id);
+	}
+
+	shutdown_pipeline (priv->play);
 	g_free (priv->play);
 
-	gst_element_set_state (priv->record->pipeline, GST_STATE_NULL);
-	gst_object_unref (GST_OBJECT (priv->record->pipeline));
+	shutdown_pipeline (priv->record);
 	g_free (priv->record);
 
 	unlink (priv->record_filename);
@@ -733,7 +749,7 @@ fill_in_information (GSRWindow *window,
 	/* filename */
 	name = g_path_get_basename (window->priv->filename);
 	if (window->priv->dirty) {
-		text = g_strdup_printf (_("%s (Has not been saved"), name);
+		text = g_strdup_printf (_("%s (Has not been saved)"), name);
 	} else {
 		text = g_strdup (name);
 	}
@@ -757,7 +773,7 @@ fill_in_information (GSRWindow *window,
 	          till we can get the info */
 	/* Length */
 	if (window->priv->len_secs == 0) {
-		text = g_strdup (_("Unknown length"));
+		text = g_strdup (_("Unknown"));
 	} else {
 		text = seconds_to_full_string (window->priv->len_secs);
 	}
@@ -768,7 +784,7 @@ fill_in_information (GSRWindow *window,
 	if (window->priv->samplerate == 0) {
 		text = g_strdup (_("Unknown"));
 	} else {
-		text = g_strdup_printf (_("%.1f khz/s"), (float) window->priv->samplerate / 1000);
+		text = g_strdup_printf (_("%.1f kHz"), (float) window->priv->samplerate / 1000);
 	}
 	gtk_label_set_text (GTK_LABEL (fp->samplerate), text);
 	g_free (text);
@@ -828,21 +844,21 @@ file_properties (BonoboUIComponent *uic,
 	dialog = gtk_dialog_new_with_buttons (title, GTK_WINDOW (window),
 					      GTK_DIALOG_DESTROY_WITH_PARENT,
 					      GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE, NULL);
-
+	gtk_window_set_resizable (GTK_WINDOW(dialog), FALSE);
 	fp = g_new (struct _file_props, 1);
 	fp->dialog = dialog;
 	
 	g_signal_connect (G_OBJECT (dialog), "response",
 			  G_CALLBACK (dialog_closed), fp);
 
-	gtk_container_set_border_width (GTK_CONTAINER (dialog), 6);
-	vbox = gtk_vbox_new (FALSE, 18);
+	vbox = gtk_vbox_new (FALSE, 12);
+	gtk_container_set_border_width (GTK_CONTAINER (vbox), 6);
 	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox), vbox, TRUE, TRUE, 0);
 
 	inner_vbox = gtk_vbox_new (FALSE, 6);
 	gtk_box_pack_start (GTK_BOX (vbox), inner_vbox, FALSE, FALSE,0);
 
-	label = make_title_label (_("File Information:"));
+	label = make_title_label (_("File Information"));
 	gtk_box_pack_start (GTK_BOX (inner_vbox), label, FALSE, FALSE, 0);
 
 	hbox = gtk_hbox_new (FALSE, 0);
@@ -856,19 +872,19 @@ file_properties (BonoboUIComponent *uic,
 	gtk_table_set_col_spacings (GTK_TABLE (table), 12);
 	gtk_box_pack_start (GTK_BOX (hbox), table, TRUE, TRUE, 0);
 
-	label = make_title_label (_("Directory:"));
+	label = make_info_label (_("Folder:"));
 	pack_table_widget (table, label, 0, 0);
 
 	fp->dirname = make_info_label ("");
 	pack_table_widget (table, fp->dirname, 1, 0);
 
-	label = make_title_label (_("Filename:"));
+	label = make_info_label (_("Filename:"));
 	pack_table_widget (table, label, 0, 1);
 
 	fp->filename = make_info_label ("");
 	pack_table_widget (table, fp->filename, 1, 1);
 
-	label = make_title_label (_("File size:"));
+	label = make_info_label (_("File size:"));
 	pack_table_widget (table, label, 0, 2);
 
 	fp->size = make_info_label ("");
@@ -877,7 +893,7 @@ file_properties (BonoboUIComponent *uic,
 	inner_vbox = gtk_vbox_new (FALSE, 6);
 	gtk_box_pack_start (GTK_BOX (vbox), inner_vbox, FALSE, FALSE, 0);
 
-	label = make_title_label (_("Audio Information:"));
+	label = make_title_label (_("Audio Information"));
 	gtk_box_pack_start (GTK_BOX (inner_vbox), label, FALSE, FALSE, 0);
 
 	hbox = gtk_hbox_new (FALSE, 0);
@@ -891,25 +907,25 @@ file_properties (BonoboUIComponent *uic,
 	gtk_table_set_col_spacings (GTK_TABLE (table), 12);
 	gtk_box_pack_start (GTK_BOX (hbox), table, TRUE, TRUE, 0);
 
-	label = make_title_label (_("Song length:"));
+	label = make_info_label (_("Song length:"));
 	pack_table_widget (table, label, 0, 0);
 
 	fp->length = make_info_label ("");
 	pack_table_widget (table, fp->length, 1, 0);
 
-	label = make_title_label (_("Number of channels:"));
+	label = make_info_label (_("Number of channels:"));
 	pack_table_widget (table, label, 0, 1);
 
 	fp->channels = make_info_label ("");
 	pack_table_widget (table, fp->channels, 1, 1);
 
-	label = make_title_label (_("Sample rate:"));
+	label = make_info_label (_("Sample rate:"));
 	pack_table_widget (table, label, 0, 2);
 
 	fp->samplerate = make_info_label ("");
 	pack_table_widget (table, fp->samplerate, 1, 2);
 
-	label = make_title_label (_("Bit rate:"));
+	label = make_info_label (_("Bit rate:"));
 	pack_table_widget (table, label, 0, 3);
 
 	fp->bitrate = make_info_label ("");
@@ -919,6 +935,12 @@ file_properties (BonoboUIComponent *uic,
 	gtk_widget_show_all (dialog);
 }
 
+void
+gsr_window_close (GSRWindow *window)
+{
+	gtk_widget_destroy (GTK_WIDGET (window));
+}
+
 static void
 file_close (BonoboUIComponent *uic,
 	    GSRWindow *window,
@@ -942,6 +964,23 @@ file_quit (BonoboUIComponent *uic,
 	gsr_quit ();
 }
 
+static void
+help_contents (BonoboUIComponent *component,
+	       GSRWindow *window,
+	       const char *path)
+{
+	GError *error = NULL;
+
+	gnome_help_display ("gnome-sound-recorder.xml", NULL, &error);
+
+	if (error != NULL)
+	{
+		g_warning (error->message);
+
+		g_error_free (error);
+	}
+}
+
 static void
 help_about (BonoboUIComponent *uic,
 	    GSRWindow *window,
@@ -954,10 +993,9 @@ help_about (BonoboUIComponent *uic,
 		gdk_window_raise (about->window);
 		gdk_window_show (about->window);
 	} else {
-		about = gnome_about_new ("Sound Recorder", VERSION,
-					 "Copyright (C) 2002",
-					 "A sound recorder\n"
-					 "http://www.gnome.org",
+		about = gnome_about_new (_("Sound Recorder"), VERSION,
+					 "Copyright \xc2\xa9 2002 Iain Holmes",
+					 _("A sound recorder for GNOME"),
 					 authors, NULL, NULL, NULL);
 		g_signal_connect (G_OBJECT (about), "destroy",
 				  G_CALLBACK (gtk_widget_destroyed), &about);
@@ -1032,6 +1070,7 @@ static BonoboUIVerb file_verbs[] = {
 };
 
 static BonoboUIVerb help_verbs[] = {
+	BONOBO_UI_VERB ("HelpContents", (BonoboUIVerbFn) help_contents),
 	BONOBO_UI_VERB ("HelpAbout", (BonoboUIVerbFn) help_about),
 
 	BONOBO_UI_VERB_END
@@ -1065,7 +1104,7 @@ get_length (GSRWindow *window)
 
 	if (window->priv->play->sink != NULL) {
 		query_worked = gst_element_query (window->priv->play->sink,
-						  GST_PAD_QUERY_TOTAL, &format, &value);
+						  GST_QUERY_TOTAL, &format, &value);
 	}
 
 	if (query_worked) {
@@ -1135,7 +1174,7 @@ tick_callback (GSRWindow *window)
 	}
 
 	query_worked = gst_element_query (window->priv->play->sink,
-					  GST_PAD_QUERY_POSITION, 
+					  GST_QUERY_POSITION, 
 					  &format, &value);
 	if (query_worked) {
 		double percentage;
@@ -1173,7 +1212,7 @@ play_state_changed (GstElement *element,
 	switch (state) {
 	case GST_STATE_PLAYING:
 		g_idle_add ((GSourceFunc) play_iterate, window);
-		g_timeout_add (200, (GSourceFunc) tick_callback, window);
+		window->priv->tick_id = g_timeout_add (200, (GSourceFunc) tick_callback, window);
 		if (window->priv->len_secs == 0) {
 			window->priv->get_length_attempts = 16;
 			g_timeout_add (200, (GSourceFunc) get_length, window);
@@ -1265,8 +1304,10 @@ make_play_pipeline (GSRWindow *window)
 	GSRWindowPipeline *pipeline = g_new (GSRWindowPipeline, 1);
 
 	pipeline->pipeline = gst_pipeline_new ("play-pipeline");
-	g_signal_connect (G_OBJECT (pipeline->pipeline), "state-change",
-			  G_CALLBACK (play_state_changed), window);
+	pipeline->state_change_id = g_signal_connect (G_OBJECT (pipeline->pipeline),
+						      "state-change",
+						      G_CALLBACK (play_state_changed),
+						      window);
 	g_signal_connect (G_OBJECT (pipeline->pipeline), "deep-notify",
 			  G_CALLBACK (play_deep_notify), window);
 
@@ -1353,8 +1394,10 @@ make_record_pipeline (GSRWindow *window)
 	GSRWindowPipeline *pipeline = g_new (GSRWindowPipeline, 1);
 
 	pipeline->pipeline = gst_thread_new ("record-pipeline");
-	g_signal_connect (G_OBJECT (pipeline->pipeline), "state-change",
-			  G_CALLBACK (record_state_changed), window);
+	pipeline->state_change_id = g_signal_connect (G_OBJECT (pipeline->pipeline),
+						      "state-change",
+						      G_CALLBACK (record_state_changed),
+						      window);
 	pipeline->src = gst_element_factory_make ("osssrc", "src");
 	encoder = gst_element_factory_make ("wavenc", "encoder");
 	if (encoder == NULL) {
@@ -1569,9 +1612,3 @@ gsr_window_new (const char *filename)
 	gtk_widget_show_all (window->priv->main_vbox);
 	return GTK_WIDGET (window);
 }
-
-void
-gsr_window_close (GSRWindow *window)
-{
-	gtk_widget_destroy (GTK_WIDGET (window));
-}
